@@ -5,9 +5,7 @@
 #define ZLIB_FOUND
 #define CUPDLP_CPU
 /* #undef CUPDLP_GPU */
-/* #undef CUPDLP_FORCE_NATIVE */
 #define CMAKE_BUILD_TYPE "Release"
-#define CMAKE_INSTALL_PREFIX "/clangarm64"
 /* #undef HIGHSINT64 */
 /* #undef HIGHS_NO_DEFAULT_THREADS */
 /* #undef HIGHS_HAVE_MM_PAUSE */
@@ -16,8 +14,7 @@
 
 #define HIGHS_GITHASH "n/a"
 #define HIGHS_VERSION_MAJOR 1
-#define HIGHS_VERSION_MINOR 10
+#define HIGHS_VERSION_MINOR 11
 #define HIGHS_VERSION_PATCH 0
-#define HIGHS_DIR "C:/M/B/src/HiGHS-1.10.0"
 
 #endif /* HCONFIG_H_ */
